# ------------------------------------------------------------------------------
#
# SketchUp Window Settings
#
# Homepage
#   http://sketchucation.com/forums/viewtopic.php?f=323&t=42926
#
# Description
#   SketchUp Window Settings plugin allows you to set main window fullscreen,
#   show/hide menubar, toolbar containers, statusbar, scenesbar and more
#   elements of the window. This tool comes in handy for those with small
#   monitors, or simply for those who aim to get the maximum out of their
#   rendering.
#
# Usage
#   Test through menu options and the dialog, you'll figure it out. You may also
#   assign menu shortcuts such as F11 to toggle full screen.
#
# Localization
#   I have added localization, but most of them were not user reviewed. If
#   you're not satisfied with the translations you can simply erase the
#   ../ams_WindowSettings/lang folder to set default English translations, or
#   modify the current translations till you're satisfied.
#
# Access
#   (Menu) Window -> Settings -> Settings Dialog
#
# Requirements
#   * Microsoft Windows XP, Vista, 7, 8
#   * SketchUp 6 or later
#   * AMS_Library 1.0.5 or later
#
# Version
#   3.5.4
#
# Release Date
#   December 18, 2013
#
# Thanks to
#   * Dan Rathbun, ThomThom, Chris, and many other SketchUcation members for
#     improving my scripting level.
#   * Aerilius for the code snippets in his ae_LaunchUp plugin.
#   * Aleksey Synytsia (My dad) for helping out with MSFT Windows API.
#   * Rich O Brien, CadFather, feodos, Burkhard, and other for ideas,
#     suggestions, and reporting bugs.
#
# Copyright
#   © 2011-2013, Anton Synytsia.
#
# License
#   GNU -- http://opensource.org/licenses/GPL-3.0
#
# Author
#   Anton Synytsia
#
# Contact
#   anton.synytsia@gmail.com
#
# ------------------------------------------------------------------------------

require 'sketchup.rb'
require 'extensions.rb'

dir = File.dirname(__FILE__)
lib = File.join(dir, 'ams_Lib.rb')
win = ( RUBY_PLATFORM =~ /mswin|mingw/i )

continue = true

# Check operating system, and make decisions prior to loading.
unless win
  msg = "It seems your operating system is not Microsoft Windows. "
  msg << "SU Window Settings extension might not operate on your OS.\n"
  msg << "Load the extension anyway?"
  input = UI.messagebox(msg, MB_YESNO)
  continue = false if (input == IDNO)
end

# Check for AMS Library.
if continue
  if File.exists?(lib)
    require 'ams_Lib.rb'
    if AMS::Lib::VERSION.delete('.').to_i < 105
      msg = "SU Window Settings extension requires AMS Library version 1.0.5 or later! "
      msg << "Download AMS Library, extract it into the Plugins folder, and then restart SketchUp.\n"
      msg << "Click OK to proceed to the library's homepage."
      input = UI.messagebox(msg, MB_OKCANCEL)
      if input == IDOK
        UI.openURL('http://sketchucation.com/forums/viewtopic.php?f=323&t=55067#p499835')
      end
      continue = false
    end
  else
    msg = "SU Window Settings extension requires AMS Library! "
    msg << "Download AMS Library, extract it into the Plugins folder, and then restart SketchUp.\n"
    msg << "Click OK to proceed to the library's homepage."
    input = UI.messagebox(msg, MB_OKCANCEL)
    if input == IDOK
      UI.openURL('http://sketchucation.com/forums/viewtopic.php?f=323&t=55067#p499835')
    end
    continue = false
  end
end

module AMS::Plugins::WindowSettings

  NAME         = 'SU Window Settings'.freeze
  VERSION      = '3.5.4'.freeze
  RELEASE_DATE = 'December 18, 2013'.freeze

  # Create the extension.
  @extension = SketchupExtension.new NAME, 'ams_WindowSettings/main.rb'

  desc = "Allows you to set main window fullscreen, show/hide menubar, toolbar"
  desc << "containers, statusbar, scenesbar and more elements of the window. "
  desc << "This tool comes in handy for those with small monitors, or simply "
  desc << "for those who aim to get the maximum out of their rendering."

  # Attach some nice info.
  @extension.description = desc
  @extension.version     = VERSION
  @extension.copyright   = 'Anton Synytsia © 2013'
  @extension.creator     = 'Anton Synytsia (anton.synytsia@gmail.com)'

  # Register and load the extension on start-up.
  Sketchup.register_extension @extension, true

  class << self
    attr_reader :extension
  end

end if continue
